==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","");
define("_OK","!");
define("_COMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","  ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD"," ");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","  ");
define("_COMMENTSWARNING","  .     .");
define("_SCORE",":");
define("_USERINFO"," ");
define("_READREST","  ...");
define("_REPLY","  ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT","  ");
define("_NOANONCOMMENTS","   ,  <a href=\"modules.php?name=Your_Account\"></a>");
define("_PARENT","");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML","HTML :");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","");
define("_SURVEYCOM","Survey Comment Post");
define("_SURVEYCOMPRE","Survey Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG"," ");
define("_PASTSURVEYS"," ");



define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_VOTING"," ");
define("_OTHERPOLLS"," ");
define("_CURRENTSURVEY"," ");
define("_CURRENTPOLLRESULTS","  ");
define("_PREVIEW","");
define("_REFRESH","");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-arabic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","");
define("_OK","!");
define("_COMMENT","");
define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","Threshold");
define("_NOCOMMENTS","  ");
define("_NESTED","");
define("_FLAT","");
define("_THREAD"," ");
define("_OLDEST"," ");
define("_NEWEST"," ");
define("_HIGHEST","  ");
define("_COMMENTSWARNING","  .     .");
define("_SCORE",":");
define("_USERINFO"," ");
define("_READREST","  ...");
define("_REPLY","  ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT","  ");
define("_NOANONCOMMENTS","   ,  <a href=\"modules.php?name=Your_Account\"></a>");
define("_PARENT","");
define("_ROOT","Root");
define("_UCOMMENT","");
define("_ALLOWEDHTML","HTML :");
define("_POSTANON","Post Anonymously");
define("_EXTRANS","Extrans (html tags to text)");
define("_HTMLFORMATED","HTML Formated");
define("_PLAINTEXT","Plain Old Text");
define("_ONN","on...");
define("_SUBJECT","");
define("_SURVEYCOM","Survey Comment Post");
define("_SURVEYCOMPRE","Survey Comment Post Preview");
define("_NOTRIGHT","Something is not right with passing a variable to this function. This message is just to keep things from messing up down the road");
define("_DIRECTCOM","Direct Survey Comment...");
define("_SENDAMSG"," ");
define("_PASTSURVEYS"," ");



define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_VOTING"," ");
define("_OTHERPOLLS"," ");
define("_CURRENTSURVEY"," ");
define("_CURRENTPOLLRESULTS","  ");
define("_PREVIEW","");
define("_REFRESH","");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
